@@ -17,7 +17,7 @@ use Carp;
 use vars qw($VERSION @ISA @EXPORT $AUTOLOAD
 		$use_XSLoader);
 
-$VERSION = '0.33';
+$VERSION = '0.34';
 
 require Exporter;
 #require DynaLoader;
@@ -158,6 +158,10 @@ BEGIN {
 	DB_FIXEDLEN
 	DB_FLUSH
 	DB_FORCE
+	DB_FOREIGN_ABORT
+	DB_FOREIGN_CASCADE
+	DB_FOREIGN_CONFLICT
+	DB_FOREIGN_NULLIFY
 	DB_FREELIST_ONLY
 	DB_FREE_SPACE
 	DB_GETREC
@@ -234,11 +238,15 @@ BEGIN {
 	DB_LOGOLDVER
 	DB_LOGVERSION
 	DB_LOG_AUTOREMOVE
+	DB_LOG_AUTO_REMOVE
 	DB_LOG_BUFFER_FULL
 	DB_LOG_CHKPNT
 	DB_LOG_COMMIT
+	DB_LOG_DIRECT
 	DB_LOG_DISK
+	DB_LOG_DSYNC
 	DB_LOG_INMEMORY
+	DB_LOG_IN_MEMORY
 	DB_LOG_LOCKED
 	DB_LOG_NOCOPY
 	DB_LOG_NOT_DURABLE
@@ -246,6 +254,7 @@ BEGIN {
 	DB_LOG_RESEND
 	DB_LOG_SILENT_ERR
 	DB_LOG_WRNOSYNC
+	DB_LOG_ZERO
 	DB_MAX_PAGES
 	DB_MAX_RECORDS
 	DB_MPOOL_CLEAN
@@ -259,6 +268,7 @@ BEGIN {
 	DB_MPOOL_NEW
 	DB_MPOOL_NEW_GROUP
 	DB_MPOOL_NOFILE
+	DB_MPOOL_NOLOCK
 	DB_MPOOL_PRIVATE
 	DB_MPOOL_UNLINK
 	DB_MULTIPLE
@@ -351,6 +361,7 @@ BEGIN {
 	DB_REPMGR_ACKS_ONE
 	DB_REPMGR_ACKS_ONE_PEER
 	DB_REPMGR_ACKS_QUORUM
+	DB_REPMGR_CONF_2SITE_STRICT
 	DB_REPMGR_CONNECTED
 	DB_REPMGR_DISCONNECTED
 	DB_REPMGR_PEER
@@ -361,6 +372,7 @@ BEGIN {
 	DB_REP_CLIENT
 	DB_REP_CONF_BULK
 	DB_REP_CONF_DELAYCLIENT
+	DB_REP_CONF_LEASE
 	DB_REP_CONF_NOAUTOINIT
 	DB_REP_CONF_NOWAIT
 	DB_REP_CONNECTION_RETRY
@@ -374,6 +386,8 @@ BEGIN {
 	DB_REP_FULL_ELECTION
 	DB_REP_FULL_ELECTION_TIMEOUT
 	DB_REP_HANDLE_DEAD
+	DB_REP_HEARTBEAT_MONITOR
+	DB_REP_HEARTBEAT_SEND
 	DB_REP_HOLDELECTION
 	DB_REP_IGNORE
 	DB_REP_ISPERM
@@ -401,6 +415,7 @@ BEGIN {
 	DB_RPC_SERVERVERS
 	DB_RUNRECOVERY
 	DB_SALVAGE
+	DB_SA_SKIPFIRSTKEY
 	DB_SECONDARY_BAD
 	DB_SEQUENCE_OLDVER
 	DB_SEQUENCE_VERSION
@@ -425,8 +440,17 @@ BEGIN {
 	DB_STAT_LOCK_OBJECTS
 	DB_STAT_LOCK_PARAMS
 	DB_STAT_MEMP_HASH
+	DB_STAT_MEMP_NOERROR
 	DB_STAT_NOERROR
 	DB_STAT_SUBSYSTEM
+	DB_ST_DUPOK
+	DB_ST_DUPSET
+	DB_ST_DUPSORT
+	DB_ST_IS_RECNO
+	DB_ST_OVFL_LEAF
+	DB_ST_RECNUM
+	DB_ST_RELEN
+	DB_ST_TOPLEVEL
 	DB_SURPRISE_KID
 	DB_SWAPBYTES
 	DB_SYSTEM_MEM
@@ -457,7 +481,6 @@ BEGIN {
 	DB_TXNVERSION
 	DB_TXN_ABORT
 	DB_TXN_APPLY
-	DB_TXN_BACKWARD_ALLOC
 	DB_TXN_BACKWARD_ROLL
 	DB_TXN_CKP
 	DB_TXN_FORWARD_ROLL
@@ -497,6 +520,13 @@ BEGIN {
 	DB_VERB_RECOVERY
 	DB_VERB_REGISTER
 	DB_VERB_REPLICATION
+	DB_VERB_REPMGR_CONNFAIL
+	DB_VERB_REPMGR_MISC
+	DB_VERB_REP_ELECT
+	DB_VERB_REP_LEASE
+	DB_VERB_REP_MISC
+	DB_VERB_REP_MSGS
+	DB_VERB_REP_SYNC
 	DB_VERB_WAITSFOR
 	DB_VERIFY
 	DB_VERIFY_BAD
